.. |channels| replace:: :term:`channels<channel>`
.. |Complete samples| replace:: :term:`Complete samples<complete sample>`
.. |complete samples| replace:: :term:`complete samples<complete sample>`
.. |components| replace:: :term:`components<component>`
.. |data frames| replace:: :term:`data frames<data frame>`
.. |elementary samples| replace:: :term:`elementary samples<elementary sample>`
.. |Elementary samples| replace:: :term:`elementary samples<elementary sample>`
.. |frame| replace:: :term:`frame<data frame>`
.. |frames| replace:: :term:`frames<data frame>`
.. |frameset| replace:: :term:`frameset<data frame>`
.. |framesets| replace:: :term:`framesets<data frameset>`
.. |headers| replace:: :term:`headers<header>`
.. |payloads| replace:: :term:`payloads<payload>`
.. |samples| replace:: :term:`samples<sample>`
.. |squeezed| replace:: :term:`squeezed<squeezing>`
.. |threads| replace:: :term:`threads<thread>`